import { Page, expect } from '@playwright/test'

import {
  byTestId,
  clickElementByTestId,
  donationsRequestTimeout,
  proceedAsGuest,
  volunteeringRequestTimeout,
} from './helpers'
import { test } from './testmaster'

test.describe('@ActPage', () => {
  test('user journey', async ({ page }) => {
    // prepare
    await proceedAsGuest(page)

    await page.goto('/act')
    // act page is open and contain apps
    await page.waitForSelector(byTestId('volunteering-app-updates-list'))
    await page.waitForSelector(byTestId('donations-app-updates-list'))

    await openAppAndReturn(page, 'volunteering', volunteeringRequestTimeout)
    await openAppAndReturn(page, 'donations', donationsRequestTimeout)
  })
})

const openAppAndReturn = async (page: Page, appName: string, appTimeout: number) => {
  // open the volunteering list
  await clickElementByTestId(page, `${appName}-updates-heading-button`)

  // app is open
  await page.waitForSelector(byTestId(`${appName}-list-container`), { timeout: appTimeout })
  expect(page.url()).toContain(`/${appName}`)

  // go back home
  await clickElementByTestId(page, 'nav-button-back')
}
